@@ -3,32 +3,9 @@
   kwidgetlister.cpp
 
   This file is part of libkdepim.
-  Copyright (c) 2001 Marc Mutz <mutz@kde.org>
+  SPDX-FileCopyrightText: 2001 Marc Mutz <mutz@kde.org>
 
-  This library is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this library with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt.  If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kwidgetlister.h"
@@ -107,7 +84,7 @@ void KWidgetLister::init(bool fewerMoreButton)
     d->mLayout->setSpacing(4);
 
     d->mButtonBox = new QWidget(this);
-    QHBoxLayout *mButtonBoxHBoxLayout = new QHBoxLayout(d->mButtonBox);
+    auto *mButtonBoxHBoxLayout = new QHBoxLayout(d->mButtonBox);
     mButtonBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mLayout->addWidget(d->mButtonBox);
 
